import type { Octokit } from "@octokit/core";
import type { Endpoints } from "@octokit/types";
export declare type TreeParameter = Endpoints["POST /repos/{owner}/{repo}/git/trees"]["parameters"]["tree"];
export declare type Options = {
    owner: string;
    repo: string;
    title: string;
    body: string;
    head: string;
    changes: Changes | Changes[];
    labels?: String[];
    base?: string;
    createWhenEmpty?: boolean;
    draft?: boolean;
    forceFork?: boolean;
    update?: boolean;
};
export declare type Changes = {
    files?: {
        [path: string]: string | File | UpdateFunction | null | Symbol;
    };
    emptyCommit?: boolean | string;
    commit: string;
    committer?: Committer;
    author?: Author | undefined;
    signature?: SignatureFunction | undefined;
};
export declare type File = {
    content: string;
    encoding: "utf-8" | "base64";
    mode?: string;
};
export declare type SignatureFunction = (commitPayload: CommitPayload) => string;
export declare type UpdateFunctionFile = {
    exists: true;
    size: number;
    encoding: "base64";
    content: string;
} | {
    exists: false;
    size: never;
    encoding: never;
    content: never;
};
export declare type UpdateFunction = (file: UpdateFunctionFile) => string | File | null | Symbol | Promise<string | File | null | Symbol>;
export declare type State = {
    octokit: Octokit;
    owner: string;
    repo: string;
    ownerOrFork?: string;
    latestCommitSha?: string;
    latestCommitTreeSha?: string;
    treeSha?: string;
};
export declare type Committer = {
    name?: string;
    email?: string;
    date?: string;
};
export declare type Author = {
    name: string;
    email: string;
    date?: string;
};
export declare type CommitPayload = {
    message: string;
    tree: string;
    parents: string[];
    author?: Author;
    committer?: Committer;
};
